/************************************************************************/
/*  bhold -	create holdings record for SEED blockettes.		*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: bhold.c,v 1.2 2000/10/26 13:39:12 doug Exp $ ";
#endif

/*  Changeable defaults.	*/

#ifndef	DEFAULT_DCC
#define	DEFAULT_DCC		"BK"
#endif

#ifndef	DEFAULT_OPERATOR
#define	DEFAULT_OPERATOR	"XX"
#endif

#ifndef	DEFAULT_HEADER_DIR
#define	DEFAULT_HEADER_DIR	"HDR000"
#endif

#ifndef	DEFAULT_NETWORK
#define	DEFAULT_NETWORK		"BK"
#endif

#include <stdio.h>
#include "version.h"
   
char *syntax[] = {
"%s version " VERSION,
"%s  [-D dcc] [-H header_dir] [-O operator] [-N network ] [-h]",
"    input_dir_1 [ ... input_dir_n]",
"    where:",
"	-D dcc	    specifies the (2 character) name of the DCC.",
"		    Default is " DEFAULT_DCC ".",
"	-H hdrdir   specifies the partial name of the header directory.",
"		    Default is " DEFAULT_HEADER_DIR ".",
"	-O operator specifies the (2 character) initials of the operator.",
"		    Default is " DEFAULT_OPERATOR ".",
"	-N network  specifies the (2 character) network name for V2.3 holdings",
"		    if network field is not specified in the station blockette.",
"		    Default is " DEFAULT_NETWORK ".",
"	-h	    Help - prints syntax message.",
"	input_dir_1 ... input_dir_n",
"		    specifies the input directories for the stations.",
NULL };

/************************************************************************/
#define	EXTERN

#include "qlib2.h"

#include "holdings.h"
#include "rdseed.h"
#include "externals.h"
#include "procs.h"

/************************************************************************/
/*  main:   main program.						*/
/************************************************************************/
main (int argc, char **argv)
{
    int nfiles;

    /* Variables needed for getopt. */
    extern char	*optarg;
    extern int	optind, opterr;
    int		c;
    
    /*	Initialization.							*/
    info = stderr;
    seed_version = 2.3;
    header_dir = DEFAULT_HEADER_DIR;
    operator = DEFAULT_OPERATOR;
    dcc = DEFAULT_DCC;
    /*	A null network is valid, since it implies that we use the	*/
    /*	network_id from the data file.					*/

    cmdname = tail(*argv);
    get_my_wordorder();

    /*	Parse command line options.					*/
    while ( (c = getopt(argc,argv,"hH:O:D:N:")) != -1)
    switch (c) {
      case '?':
      case 'h': print_syntax(cmdname, syntax, stdout); exit(0); break;
      case 'H': header_dir = optarg; break;
      case 'O': operator = optarg; break;
      case 'D': dcc = optarg; break;
      case 'N':	network = optarg; break;
      default:	
	fprintf (stdout, "Illegal option: -%c\n", c);
	print_syntax(cmdname, syntax, stdout);
	exit(1); 
	break;
    }

    /*	Skip over all options and their arguments.			*/
    argv += optind;
    argc -= optind;

    /* The remaining arguments are the input files.			*/
    nfiles = argc;
    if (nfiles <= 0) {
	print_syntax (cmdname, syntax, stdout);
	exit(1);
    }

    while (argc-- > 0) {
	make_holdings (*argv++);
    }
    return(0);
}

