/************************************************************************/
/*  Routine for making holdings entry.					*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: make_holdings.c,v 1.3 2000/10/26 13:39:13 doug Exp $ ";
#endif

#include <stdio.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/param.h>
#ifndef MAXPATHLEN
#define	MAXPATHLEN  2048
#endif

#include "qlib2.h"

#include "holdings.h"
#include "rdseed.h"
#include "externals.h"
#include "procs.h"

#define	MAX_BLOCKETTE_LEN	32768

static char *dummy_end = "2499,365,23:59:59.9999";
static char *dummy_filename = "";

/************************************************************************/
/*  make_holdings:							*/
/*	Create holdings entry for the specified station.		*/
/************************************************************************/
int make_holdings
   (char	*station_dir)	/* station directory with blockettes.	*/
{
    INT_TIME	*stime;
    INT_TIME	*etime;
    DIR		*sdp;
    struct dirent *dp;
    FILE	*fp;
    struct stat	sb;
    int		blen;
    char	blen_str[5];
    char	file_050[MAXPATHLEN];
    char	file_052[MAXPATHLEN];
    char	channel_dir[MAXPATHLEN];
    char	blockette[MAX_BLOCKETTE_LEN];
    struct type50 *type50 = NULL;
    struct type52 *type52 = NULL;
    int		b050_found = 0;
    int		b052_found = 0;

    if (stat(station_dir,&sb) == 0 && ! S_ISDIR(sb.st_mode)) {
	return(0);
    }

    /* Parse Blockette 50 before we look for channels.			*/
    sprintf (file_050, "%s/%s", station_dir, "B050");
    if ((fp = fopen(file_050, "r")) == NULL) {
	fprintf (stderr, "Unable to open B050 file: %s\n", file_050);
	return(0);
    }
    blockette[MAX_BLOCKETTE_LEN-1] = '\0';
    while (fgets(blockette, MAX_BLOCKETTE_LEN-1, fp) != NULL) {
	if (strlen(blockette) <= 8) {
	    fprintf (stderr, "Invalid blockette in: %s\n", file_050);
	    break;
	}
	strncpy (blen_str, blockette+3, 4);
	blen_str[4] = '\0';
	blen = atoi(blen_str);
	if (blen != strlen(blockette)-1) {
	    fprintf (stderr, "blockette length error: len = %d, hdr = %d in file: %s\n",
		     strlen(blockette)-1, blen, file_050);
	    break;
	}
	if (strncmp(blockette, "050", 3) == 0) {
	    type50 = parse_type50(blockette);
	    ++b050_found;
	    break;
	}
    }
    fclose(fp);
    if (! b050_found) {
	fprintf (stderr, "No blockette 050 found in: %s\n", file_050);
	return (0);
    }

    /* Open the station directory.					*/
    if ((sdp = opendir(station_dir)) == NULL) {
	fprintf (stderr, "Unable to open dir: %s\n", station_dir);
	return(0);
    }

    /* For each directory in station directory, look for B052 file.	*/
    for (dp = readdir(sdp); dp != NULL; dp = readdir(sdp)) {
	if (dp->d_name[0] == '.') continue;
	sprintf (channel_dir, "%s/%s", station_dir, dp->d_name);
	if (stat(channel_dir,&sb) == 0 && S_ISDIR(sb.st_mode)) {
	    sprintf (file_052, "%s/%s", channel_dir, "B052");
	    if ((fp = fopen(file_052, "r")) == NULL) {
		fprintf (stderr, "Unable to open B052 file: %s\n", file_052);
		continue;
	    }
	    /* Loop through B052 file and find each blockette 52.	*/
	    b052_found = 0;
	    blockette[MAX_BLOCKETTE_LEN-1] = '\0';
	    while (fgets(blockette, MAX_BLOCKETTE_LEN-1, fp) != NULL) {
		if (strlen(blockette) <= 8) {
		    fprintf (stderr, "Invalid blockette in: %s\n", file_052);
		    break;
		}
		strncpy (blen_str, blockette+3, 4);
		blen_str[4] = '\0';
		blen = atoi(blen_str);
		if (blen+1 != strlen(blockette)) {
		    fprintf (stderr, "blockette wrong length, or too long: %s\n",
			     file_052);
		    break;
		}
		if (strncmp(blockette, "052", 3) == 0) {
		    type52 = parse_type52(blockette);
		    write_holding (type50, type52);
		    free_type52(type52);
		    ++b052_found;
		}
	    }
	    fclose(fp);
	    if (! b052_found) {
		fprintf (stderr, "No blockette 052 found in: %s\n", file_052);
		continue;
	    }
	}
    }
    free_type50(type50);
    closedir(sdp);
    return(1);
}
